==> driza-0.6.0.tar.gz: driza-0.6/Driza/dialogs/doperaciones.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from Driza.ui.dialogos.operaciones import DialogoOperaciones

class DOperaciones(DialogoOperaciones):
	"""Dialogo  de operaciones"""

	def __init__(self,parent,gestoroperaciones,vsalida):
		DialogoOperaciones.__init__(self,parent,"Dialogo casos",0,0)
		self.__gestoroperaciones=gestoroperaciones
		self.__initwidgets()
		self.__conexiones()
		self.__vsalida=vsalida
		self.__noimplementado=QLabel(None,"No implementado")
		self.__noimplementado.setText("No implementado")
		self.widgetStack1.addWidget(self.__noimplementado)
		self.listView2.addColumn("Operaciones")
	
	def show(self,operacion=None):
		self.__showarbol()
#		self.__showwidget() #Mas que para show esta funcion debe ser llamada para __conexiones
		if operacion:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[operacion].widget)
			self.listView2.ensureItemVisible(self.listView2.findItem(operacion,0))
			self.listView2.setCurrentItem(self.listView2.findItem(operacion,0))
		DialogoOperaciones.show(self)

	def accept(self):
		"""Acepta el dialogo. Coge la operacion con la que esta trabajando el usuario e inicia el procedimiento de calculo"""
	#	try:
		nombre=unicode(self.listView2.currentItem().text(0).latin1(),'iso-8859-1')
		resultado=self.__gestoroperaciones[nombre].procedimiento()
		self.__vsalida.app_obj(resultado) #Añadir a la salida el resultado
		self.__vsalida.show()
	#	except:
	#		pass #TODO: Aqui debe controlarse si no hay seleccion , si ha habido algun problema con R


	def __initwidgets(self):
		"""Añade los widgets en el widgetstack"""
		for operacion in self.__gestoroperaciones.values():
			self.widgetStack1.addWidget(operacion.widget)


	def __conexiones(self):
		self.connect(self.listView2,SIGNAL("selectionChanged ()"),self.__showwidget)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.reject)
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.accept)

	def __showarbol(self):
		"""Muestra el arbol segun el contenido de gestoroperaciones"""
		self.listView2.clear()
		descriptivo=QListViewItem(self.listView2,"Descriptivo")
		estadisticos=QListViewItem(descriptivo,u"Estadísticos")
		QListViewItem(estadisticos,"Descriptivo")
		QListViewItem(descriptivo,"tfrecuencias")
		graficos=QListViewItem(descriptivo,u"Gráficas")
		QListViewItem(graficos,"Histograma")
		QListViewItem(graficos,u"Diagrama de dispersión")

		phipotesis=QListViewItem(self.listView2,"Prueba de hipotesis")
		cmedias=QListViewItem(phipotesis,u"Comparación de medias")
		QListViewItem(cmedias,u"Comparación de medias simple")
		QListViewItem(cmedias,u"Comparación de media entre dos variables")
		QListViewItem(cmedias,"anova")
		cprop=QListViewItem(phipotesis,u"Comparación de proporciones")
		QListViewItem(cprop,u"Comparación de proporciones simple")
		QListViewItem(cprop,u"Comparación de proporciones entre dos variables")
		cvar=QListViewItem(phipotesis,u"Comparación de Varianzas")
		QListViewItem(cvar,"compvarsim")
		QListViewItem(cvar,u"Comparación de Varianzas entre dos variables")
		QListViewItem(cvar,"compvarmul")
		bajuste=QListViewItem(self.listView2,"Bondad de ajuste")
		QListViewItem(bajuste,"KS")
		QListViewItem(bajuste,"Ji Cuadrado")
		rlineal=QListViewItem(self.listView2,u"Regresión Lineal")
		QListViewItem(rlineal,u"Regresión")
		distribuciones=QListViewItem(self.listView2,"Distribuciones")
		QListViewItem(distribuciones,u"Distribución Normal")

	def __showwidget(self):
		"""Muestra el widget asociado a la seleccion actual"""
		nombre=unicode(self.listView2.currentItem().text(0).latin1(),'iso-8859-1')
		try:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[nombre].widget)
		except KeyError:
			self.widgetStack1.raiseWidget(self.__noimplementado)

==> driza-0.6.1.tar.gz: driza-0.6.1/Driza/dialogs/doperaciones.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-
#This file is part of Driza.
#
#Driza is free software; you can redistribute it and/or modify
#it under the terms of the GNU General Public License as published by
#the Free Software Foundation; either version 2 of the License, or
#(at your option) any later version.
#
#Driza is distributed in the hope that it will be useful,
#but WITHOUT ANY WARRANTY; without even the implied warranty of
#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#GNU General Public License for more details.
#
#You should have received a copy of the GNU General Public License
#along with Driza; if not, write to the Free Software
#Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

from qt import *
from Driza.ui.dialogos.operaciones import DialogoOperaciones

class DOperaciones(DialogoOperaciones):
	"""Dialogo  de operaciones"""

	def __init__(self,parent,gestoroperaciones,vsalida):
		DialogoOperaciones.__init__(self,parent,"Dialogo casos",0,0)
		self.__gestoroperaciones=gestoroperaciones
		self.__initwidgets()
		self.__conexiones()
		self.__vsalida=vsalida
		self.__noimplementado=QLabel(None,"No implementado")
		self.__noimplementado.setText("No implementado")
		self.widgetStack1.addWidget(self.__noimplementado)
		self.listView2.setRootIsDecorated(True)
		self.listView2.addColumn("Operaciones")
	
	def show(self,operacion=None):
		self.__showarbol()
#		self.__showwidget() #Mas que para show esta funcion debe ser llamada para __conexiones
		if operacion:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[operacion].widget)
			self.listView2.ensureItemVisible(self.listView2.findItem(operacion,0))
			self.listView2.setCurrentItem(self.listView2.findItem(operacion,0))
		DialogoOperaciones.show(self)

	def accept(self):
		"""Acepta el dialogo. Coge la operacion con la que esta trabajando el usuario e inicia el procedimiento de calculo"""
	#	try:
		nombre=unicode(self.listView2.currentItem().text(0).latin1(),'iso-8859-1')
		resultado=self.__gestoroperaciones[nombre].procedimiento()
		self.__vsalida.appRes(resultado) #Añadir a la salida el resultado
		self.__vsalida.hide() #TODO averiguar como hacer para que recupere el foco sin ocultar la ventana
		self.__vsalida.show()
	#	except:
	#		pass #TODO: Aqui debe controlarse si no hay seleccion , si ha habido algun problema con R


	def __initwidgets(self):
		"""Añade los widgets en el widgetstack"""
		for operacion in self.__gestoroperaciones.values():
			self.widgetStack1.addWidget(operacion.widget)


	def __conexiones(self):
		self.connect(self.listView2,SIGNAL("selectionChanged ()"),self.__showwidget)
		self.connect(self.pushButton2,SIGNAL("clicked()"),self.reject)
		self.connect(self.pushButton1,SIGNAL("clicked()"),self.accept)

	def __showarbol(self):
		"""Muestra el arbol segun el contenido de gestoroperaciones"""
		self.listView2.clear()
		descriptivo=QListViewItem(self.listView2,"Descriptivos")
		estadisticos=QListViewItem(descriptivo,u"Estadísticos")
		QListViewItem(estadisticos,"Descriptivo")
		QListViewItem(descriptivo,u"Tabla de frecuencias")
		graficos=QListViewItem(descriptivo,u"Gráficas")
		QListViewItem(graficos,"Histograma")
		QListViewItem(graficos,u"Diagrama de dispersión")
		QListViewItem(graficos,u"Diagrama de barras")

		cmedias=QListViewItem(self.listView2,u"Comparación de medias")
		QListViewItem(cmedias,u"Comparación de medias simple")
		QListViewItem(cmedias,u"Comparación de medias entre dos variables")
		QListViewItem(cmedias,u"Anova Simple")
		cprop=QListViewItem(self.listView2,u"Comparación de proporciones")
		QListViewItem(cprop,u"Comparación de proporciones simple")
		QListViewItem(cprop,u"Comparación de proporciones entre dos variables")
		cvar=QListViewItem(self.listView2,u"Comparación de Varianzas")
		QListViewItem(cvar,"compvarsim")
		QListViewItem(cvar,u"Comparación de Varianzas entre dos variables")
		QListViewItem(cvar,"compvarmul")
		bajuste=QListViewItem(self.listView2,"Bondad de ajuste")
		QListViewItem(bajuste,"KS")
		QListViewItem(bajuste,"Ji Cuadrado")
		rlineal=QListViewItem(self.listView2,u"Regresión Lineal")
		QListViewItem(rlineal,u"Regresión")
		distribuciones=QListViewItem(self.listView2,"Distribuciones")
		QListViewItem(distribuciones,u"Distribución Normal")

	def __showwidget(self):
		"""Muestra el widget asociado a la seleccion actual"""
		nombre=unicode(self.listView2.currentItem().text(0).latin1(),'iso-8859-1')
		try:
			self.widgetStack1.raiseWidget(self.__gestoroperaciones[nombre].widget)
		except KeyError:
			self.widgetStack1.raiseWidget(self.__noimplementado)
